# PostPanda Helper
[![PyPI](https://img.shields.io/pypi/v/postpanda-helper?style=flat)](https://pypi.org/project/postpanda-helper/)
[![PyPI - License](https://img.shields.io/pypi/l/postpanda-helper?style=flat)](https://pypi.org/project/postpanda-helper/)

Various helpers for PostgreSQL and Pandas 

[![Documentation](https://img.shields.io/static/v1?label=&message=Documentation&color=blue&style=for-the-badge&logo=Read+the+Docs&logoColor=white)](https://ds-mn.github.io/postpanda_helper/)